%%%%%%%%%%%%%%%%%%%
% Script to deblur an image given the Piecewise Rigid Scene Flow computed
% between stereo video frames
% as described in the paper: 
% Sellent, Rother, Roth: "Stereo Video Deblurring",
% In: ECCV 2016 (to appear)
%
% Implementation by Anita Sellent (anita.sellent@tu-dresden.de)
% 
% Computer Vision Lab Dresden
% Technische Universitaet Dresden, Germany
% 
% Last revision: July 2016
%
% This program can be used only for research purposes.
% This program is distributed WITHOUT ANY WARRANTY; 
% without even the implied warranty of MERCHANTABILITY 
% or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function out = applyKernelMatrix( image, M, height, width, colors )
%function to simplefy notation with the kernel matrix from
%makeKernelMatrixFromFlows by Kim et al.

if ~exist( 'height', 'var' )
    [ height, width, colors ] = size( image );
else
    if ~exist( 'colors', 'var' )
        colors = 1;
    end
    image = reshape( image, height, width, colors );
end

out = zeros( height, width, colors );
for c = 1:colors
    tmp = image(:,:,c);
    vect_in = reshape( tmp', height * width, 1 );

    vect_out = M * vect_in;

    out(:,:,c) = reshape( vect_out, width, height )';
end