%%%%%%%%%%%%%%%%%%%
% Script to deblur an image given the Piecewise Rigid Scene Flow computed
% between stereo video frames
% as described in the paper: 
% Sellent, Rother, Roth: "Stereo Video Deblurring",
% In: ECCV 2016 (to appear)
%
% Implementation by Anita Sellent (anita.sellent@tu-dresden.de)
% 
% Computer Vision Lab Dresden
% Technische Universitaet Dresden, Germany
% 
% Last revision: July 2016
%
% This program can be used only for research purposes.
% This program is distributed WITHOUT ANY WARRANTY; 
% without even the implied warranty of MERCHANTABILITY 
% or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function out = conv2Color( img, kernel, outputSize )
%conv2 can only deal with 2D images, not color (3D) images.
%this is a wrapper function, 

%default parameter
if nargin == 2
    outputSize = 'full';
end
doUseValid = false;

if strcmp( outputSize, 'valid' )
    doUseValid = true;
    outputSize = 'full';
end

out = imfilter( img, kernel, outputSize, 'conv', 0 );%boundary condition: zero padding

if doUseValid
    [ kh, kw ] = size( kernel );
    out = out( kh: end - kh + 1, kw: end - kw + 1, : );
end

