%%%%%%%%%%%%%%%%%%%
% Script to deblur an image given the Piecewise Rigid Scene Flow computed
% between stereo video frames
% as described in the paper: 
% Sellent, Rother, Roth: "Stereo Video Deblurring",
% In: ECCV 2016 (to appear)
%
% Implementation by Anita Sellent (anita.sellent@tu-dresden.de)
% 
% Computer Vision Lab Dresden
% Technische Universitaet Dresden, Germany
% 
% Last revision: July 2016
%
% This program can be used only for research purposes.
% This program is distributed WITHOUT ANY WARRANTY; 
% without even the implied warranty of MERCHANTABILITY 
% or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function [ fieldsL1, validL1, segs, Rt, normals, calib ] = ...
    convertDataSceneFlow( result )
%obtain the required information from the output of scene flow algorithm

%get the mappings between images
fieldsL1 = result.flow2d( :,:,: );%fields contains disparity, X flow, Y flow stacked
[ height, width, ~ ] = size( fieldsL1 );

%get occlusion information
%from scene flow algorithm ( Vogel et al. )
%energy map values:
%-1: no partner
% 0: normal data-term
% 1: occlusion
% 2: impossible
% 3: match to different label

%energy map ordering: 
% 1: cam 0 time 0 disparity
% 2: cam 1 time 0 disparity
% 3: cam 0 time 0 flow
% 4: cam 0 time 1 flow
% 5: cam 1 time 0 flow
% 6: cam 1 time 1 flow
% 7: cam 0 time 1 disparity
% 8: cam 1 time 1 disparity

%the label: is occluded
%not occluded in disparity
validL1 = true( height, width );%result.energyMap( :, :, 1 ) == 0;
%not occluded in motion
validL1 = validL1 & ( (result.energyMap( :, :, 3 ) == 0) | (result.energyMap( :, :, 3 ) == 3) );
%not disoccluded in next frame
validL1 = validL1 & ( (result.energyMap( :, :, 4 ) == 0) | (result.energyMap( :, :, 4 ) == 3) );
%clean up a bit
 se = strel( 'disk', 1 );
 validL1 = imclose( validL1, se );

%get segmentation information
%which proposal applies to which pixel
segs = result.allSolutions(:,:,1) + 1;%segments L1, R1, L2, R2; +1 to start with 1 and get correct 3D motion

%the final set of rotation/ transloation proposals
Rt = result.Rt_lin;
%the final set of normals
normals = result.N_lin;
%the calibration information
calib = struct( 'Kl', result.cam.Kl, 'Kr', result.cam.Kr, ...
                'Tl', result.cam.Tl, 'Tr', result.cam.Tr );