%%%%%%%%%%%%%%%%%%%
% Script to deblur an image given the Piecewise Rigid Scene Flow computed
% between stereo video frames
% as described in the paper: 
% Sellent, Rother, Roth: "Stereo Video Deblurring",
% In: ECCV 2016 (to appear)
%
% Implementation by Anita Sellent (anita.sellent@tu-dresden.de)
% 
% Computer Vision Lab Dresden
% Technische Universitaet Dresden, Germany
% 
% Last revision: July 2016
%
% This program can be used only for research purposes.
% This program is distributed WITHOUT ANY WARRANTY; 
% without even the implied warranty of MERCHANTABILITY 
% or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function [ wk, hk] = getMaxBounds(...
                        fieldsL1, ...
                        validL1, ...
                        tau )
%find out how big the image should be to allow flow as kernel

[ height0, width0, ~] = size( fieldsL1 );
[ X, Y] = meshgrid( (1:width0), (1:height0) );

%arange exposure time symmetric around the central instant
tau1 = -1 + 0.5* (1 - tau);
tau2 = -tau1;

%% blurring L1 with motion blur kernel
%forward blur kernel
Xn = X + tau1 .* fieldsL1(:,:,2);
wklow = min( Xn(:) );
wkhigh = max( Xn(:) );

Yn = Y + tau1 .* fieldsL1(:,:,3);
hklow = min( Yn(:) );
hkhigh = max( Yn(:) );

%backward blur kernel (use this approximation here to save transporting the backward flow to this function )
Xn = X + tau2 .* fieldsL1(:,:,2);
wklow = min( wklow, min( Xn(:) ) );
wkhigh = max( wkhigh, max( Xn(:) ) );

Yn = Y + tau2 .* fieldsL1(:,:,3);
hklow = min( hklow, min( Yn(:) ) );
hkhigh = max( hkhigh, max( Yn(:) ) );

%% express as kernel boundary
wk = ceil( max( abs( min( wklow, 0) ), abs( max( wkhigh - width0, 0 ) ) ) ) + 1;
hk = ceil( max( abs( min( hklow, 0) ), abs( max( hkhigh - height0, 0 ) ) ) ) + 1;