%%%%%%%%%%%%%%%%%%%
% Script to deblur an image given the Piecewise Rigid Scene Flow computed
% between stereo video frames
% as described in the paper: 
% Sellent, Rother, Roth: "Stereo Video Deblurring",
% In: ECCV 2016 (to appear)
%
% Implementation by Anita Sellent (anita.sellent@tu-dresden.de)
% 
% Computer Vision Lab Dresden
% Technische Universitaet Dresden, Germany
% 
% Last revision: July 2016
%
% This program can be used only for research purposes.
% This program is distributed WITHOUT ANY WARRANTY; 
% without even the implied warranty of MERCHANTABILITY 
% or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function [ M ] = makeMatrixOfRigidFull( Kl, Tl, frame, Rt, normals, ...
  seg, wk, hk, time0, time1, parameter )
%generate a deblur matrix that can deblur the full image in one motion
%with bilinear interpolation

%useTransposedNotation to be consistent with blurKernelNotation of Kim
useTransposedNotation = true;
useMatExp = parameter.useMatExp;
useZeroBoundaries = false;% false: use constant boundary conditions

step = parameter.nIntegrationSteps;

%% get information on the valid part
[ height0, width0, ~ ] = size( seg );

height = height0 + 2*hk;
width = width0 + 2*wk;

[ X, Y] = meshgrid( (1 - wk: width0 + wk), (1 - hk: height0 + hk) );

%% for each segment
segId = unique( seg );

%% call mex-file
tic
x0 = 1 - wk;
x1 = width0 + wk;
y0 = 1 - hk;
y1 = height0 + hk;
%c++ indexes for frame, seg, segId
%matlab indexes out and for coordinates
[ row, col, val ] = mx_make_matrix_of_rigid_bb( ...
    Kl, Tl, frame-1, Rt, normals, seg - 1, x0, x1, y0, y1, segId - 1, step, ...
    time0, time1, useMatExp, useZeroBoundaries, useTransposedNotation );

M = sparse( row, col, val, height*width, height*width );

tt = toc;

if parameter.doVisualize
    fprintf( 'full image 3D motion to matrix conversion took %0.2f sec.\n', tt )
end






