%%%%%%%%%%%%%%%%%%%
% Script to deblur an image given the Piecewise Rigid Scene Flow computed
% between stereo video frames
% as described in the paper: 
% Sellent, Rother, Roth: "Stereo Video Deblurring",
% In: ECCV 2016 (to appear)
%
% Implementation by Anita Sellent (anita.sellent@tu-dresden.de)
% 
% Computer Vision Lab Dresden
% Technische Universitaet Dresden, Germany
% 
% Last revision: July 2016
%
% This program can be used only for research purposes.
% This program is distributed WITHOUT ANY WARRANTY; 
% without even the implied warranty of MERCHANTABILITY 
% or FITNESS FOR A PARTICULAR PURPOSE.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
function [S_L1] = reconstructSharp3D( L1, segs, ...
    fieldsL1, ...
    Rt, normals, calib, ...
    validL1, parameter )
%given segmentation and 3D scene flow per segment, compute the sharp image

%% constants
[ height0, width0, colors ] = size( L1 );

%% find the maximal boundary transgression
[ wk, hk ] = getMaxBounds( ...
    fieldsL1, ...
    validL1, ...
    parameter.tau );

height = height0 + 2*hk;
width = width0 + 2*wk;

if parameter.doVisualize
    h1 = figure(1);
    h2 = figure(2);
end

%exposure time symmetric around zeros: assume scene flow computed motion between central instants of blurred frames    
time0 = -parameter.tau * 0.5;
time1 = parameter.tau * 0.5;

%transform into kernel via homographies!
KL1 = makeMatrixOfRigidFull( calib.Kl, calib.Tl, 1, Rt, normals, ...
        segs(:,:,1), wk, hk, time0, time1, parameter );
    
%boundary excluded from deblurring
boundL1 = false( height, width );
boundL1( hk + ( 1: height0), wk + ( 1: width0) ) = true;

%%%deblur
tic
sharp = deconvSpsSegmentColor( L1, ...
    validL1, ...
    KL1, wk, hk, ...
    boundL1, parameter );
toc
S_L1 = sharp;

%show
if parameter.doVisualize
    set(0,'CurrentFigure',h1)
    subplot 111;
    tmp = min( 1, max( 0, S_L1 ) );
    imagesc( tmp, [0,1] );
    drawnow();
    set(0,'CurrentFigure',h2)
end



